@@ -8,5 +8,5 @@
 //!```
 pub trait RussianWarship {
     /// [The only thing necessary for the triumph of evil is for good men to do nothing](https://twitter.com/Ukraine/status/1497594592438497282)
-    fn go_fuck_yourself();
+    fn go_fuck_your(self);
 }
